California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 040 - REDISTRICTING. STATE SENATE DISTRICTS. REFERENDUM. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1339774 | F.A.I.R. - FAIRNESS & ACCOUNTABILITY IN REDISTRICTING BALLOT MEASURE CMTE. WITH MAJOR FUNDING FROM CA REP. PARTY FRANK GREINKE FRIENDS OF MIMI WALTERS FOR SENATE 2012 & SEN. DUTTON FOR SUPERVISOR 2014 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1321618 | YES ON 40 - HOLD POLITICIANS ACCOUNTABLE | SUPPORT